@@ -6,7 +6,6 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-from __future__ import division, print_function, absolute_import
 
 from os.path import join as pjoin, dirname
 import io
@@ -64,11 +63,11 @@ def test_read_and_proxies():
     assert_equal(img2.shape, (1, 91282))
     # While we cannot reshape arrayproxies, all images are in-memory
     assert_true(not img2.in_memory)
-    data = img2.get_data()
+    data = img2.get_fdata()
     assert_true(data is not img2.dataobj)
     # Uncaching has no effect, images are always array images
     img2.uncache()
-    assert_true(data is not img2.get_data())
+    assert_true(data is not img2.get_fdata())
 
 
 @needs_nibabel_data('nitest-cifti2')
