@@ -17,6 +17,7 @@ from ..affines import voxel_sizes, from_matvec
 from ..volumeutils import (array_to_file, array_from_file, endian_codes,
                            Recoder)
 from ..filebasedimages import SerializableImage
+from ..filename_parser import _stringify_path
 from ..spatialimages import HeaderDataError, SpatialImage
 from ..fileholders import FileHolder
 from ..arrayproxy import ArrayProxy, reshape_dataobj
@@ -529,6 +530,7 @@ class MGHImage(SpatialImage, SerializableImage):
 
     @classmethod
     def filespec_to_file_map(klass, filespec):
+        filespec = _stringify_path(filespec)
         """ Check for compressed .mgz format, then .mgh format """
         if splitext(filespec)[1].lower() == '.mgz':
             return dict(image=FileHolder(filename=filespec))
@@ -541,7 +543,7 @@ class MGHImage(SpatialImage, SerializableImage):
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
@@ -594,7 +596,7 @@ class MGHImage(SpatialImage, SerializableImage):
         '''
         if file_map is None:
             file_map = self.file_map
-        data = self.get_data()
+        data = np.asanyarray(self.dataobj)
         self.update_header()
         hdr = self.header
         with file_map['image'].get_prepare_fileobj('wb') as mghf:
