@@ -20,7 +20,7 @@ from unittest import TestCase
 from nose.tools import (assert_true, assert_false, assert_equal,
                         assert_not_equal, assert_raises)
 
-from numpy.testing import assert_array_equal, assert_array_almost_equal
+from numpy.testing import assert_array_equal, assert_array_almost_equal, assert_warns
 from ...tests.nibabel_data import get_nibabel_data, needs_nibabel_data
 
 IO_DATA_PATH = pjoin(dirname(__file__), 'data')
@@ -39,6 +39,8 @@ DATA_FILE_4D = pjoin(IO_DATA_PATH, '4d_multiframe_test.dcm')
 DATA_FILE_EMPTY_ST = pjoin(IO_DATA_PATH, 'slicethickness_empty_string.dcm')
 DATA_FILE_4D_DERIVED = pjoin(get_nibabel_data(), 'nitest-dicom',
                              '4d_multiframe_with_derived.dcm')
+DATA_FILE_CT = pjoin(get_nibabel_data(), 'nitest-dicom',
+                     'siemens_ct_header_csa.dcm')
 
 # This affine from our converted image was shown to match our image spatially
 # with an image from SPM DICOM conversion. We checked the matching with SPM
@@ -633,6 +635,13 @@ class TestMultiFrameWrapper(TestCase):
         dw = didw.wrapper_from_file(DATA_FILE_4D_DERIVED)
         assert_equal(dw.image_shape, (96, 96, 60, 33))
 
+    @dicom_test
+    @needs_nibabel_data('nitest-dicom')
+    def test_data_unreadable_private_headers(self):
+        # Test CT image with unreadable CSA tags
+        dw = assert_warns(UserWarning, didw.wrapper_from_file, DATA_FILE_CT)
+        assert_equal(dw.image_shape, (512, 571))
+
     @dicom_test
     def test_data_fake(self):
         # Test algorithm for get_data
