@@ -7,12 +7,12 @@
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 ''' Utilities for testing '''
-from __future__ import division, print_function
 
 import re
 import os
 import sys
 import warnings
+from pkg_resources import resource_filename
 from os.path import dirname, abspath, join as pjoin
 
 import numpy as np
@@ -30,10 +30,25 @@ try:
 except ImportError:
     pass
 
-from six.moves import zip_longest
+from itertools import zip_longest
+
+
+def test_data(subdir=None, fname=None):
+    if subdir is None:
+        resource = os.path.join('tests', 'data')
+    elif subdir in ('gifti', 'nicom', 'externals'):
+        resource = os.path.join(subdir, 'tests', 'data')
+    else:
+        raise ValueError("Unknown test data directory: %s" % subdir)
+
+    if fname is not None:
+        resource = os.path.join(resource, fname)
+
+    return resource_filename('nibabel', resource)
+
 
 # set path to example data
-data_path = abspath(pjoin(dirname(__file__), '..', 'tests', 'data'))
+data_path = test_data()
 
 
 from .np_features import memmap_after_ufunc
