@@ -39,7 +39,7 @@ def resample_img2img(img_to, img_from, order=1, out_class=nib.Nifti1Image):
     from scipy import ndimage as spnd
     vox2vox = npl.inv(img_from.affine).dot(img_to.affine)
     rzs, trans = to_matvec(vox2vox)
-    data = spnd.affine_transform(img_from.get_data(),
+    data = spnd.affine_transform(img_from.get_fdata(),
                                  rzs,
                                  trans,
                                  img_to.shape,
@@ -57,7 +57,7 @@ if __name__ == '__main__':
     np.set_printoptions(suppress=True, precision=4)
     normal_fname = "Phantom_EPI_3mm_tra_SENSE_6_1.PAR"
     normal_img = parrec.load(normal_fname)
-    normal_data = normal_img.get_data()
+    normal_data = normal_img.get_fdata()
     normal_normed = gmean_norm(normal_data)
 
     print("RMS of standard image {:<44}: {}".format(
@@ -69,7 +69,7 @@ if __name__ == '__main__':
             continue
         funny_img = parrec.load(parfile)
         fixed_img = resample_img2img(normal_img, funny_img)
-        fixed_data = fixed_img.get_data()
+        fixed_data = fixed_img.get_fdata()
         difference_data = normal_normed - gmean_norm(fixed_data)
         print('RMS resliced {:<52} : {}'.format(
             parfile,
