@@ -1,11 +1,13 @@
 """ Helper functions for tests
 """
+from io import BytesIO
 
 import numpy as np
 
-from io import BytesIO
-from ..openers import Opener
+from ..openers import ImageOpener
 from ..tmpdirs import InTemporaryDirectory
+from ..optpkg import optional_package
+_, have_scipy, _ = optional_package('scipy.io')
 
 from nose.tools import assert_true
 from numpy.testing import assert_array_equal
@@ -29,32 +31,6 @@ def bytesio_round_trip(img):
     return klass.from_file_map(bytes_map)
 
 
-def bz2_mio_error():
-    """ Return True if writing mat 4 file fails
-
-    Writing an empty string can fail for bz2 objects in python 3.3:
-
-    https://bugs.python.org/issue16828
-
-    This in turn causes scipy to give this error when trying to write bz2 mat
-    files.
-
-    This won't cause a problem for scipy releases after Jan 24 2014 because of
-    commit 98ef522d99 (in scipy)
-    """
-    try:
-        import scipy.io
-    except ImportError:
-        return True
-    with InTemporaryDirectory():
-        with Opener('test.mat.bz2', 'wb') as fobj:
-            try:
-                scipy.io.savemat(fobj, {'a': 1}, format='4')
-            except ValueError:
-                return True
-    return False
-
-
 def assert_data_similar(arr, params):
     """ Check data is the same if recorded, otherwise check summaries
 
