@@ -13,12 +13,12 @@ from gzip import GzipFile
 from io import BytesIO, UnsupportedOperation
 from distutils.version import StrictVersion
 
-from ..py3k import asstr, asbytes
+from numpy.compat.py3k import asstr, asbytes
 from ..openers import Opener, ImageOpener, HAVE_INDEXED_GZIP, BZ2File
 from ..tmpdirs import InTemporaryDirectory
 from ..volumeutils import BinOpener
 
-import mock
+from unittest import mock
 from nose.tools import (assert_true, assert_false, assert_equal,
                         assert_not_equal, assert_raises)
 from ..testing import error_warnings
