@@ -22,12 +22,13 @@ from ..imageclasses import spatial_axes_first
 from unittest import TestCase
 from nose.tools import (assert_true, assert_false, assert_equal,
                         assert_not_equal, assert_raises)
-from numpy.testing import assert_array_equal, assert_array_almost_equal
+from numpy.testing import assert_array_equal, assert_array_almost_equal, assert_warns
 
 from .test_helpers import bytesio_round_trip
 from ..testing import (clear_and_catch_warnings, suppress_warnings,
                        memmap_after_ufunc)
 from ..tmpdirs import InTemporaryDirectory
+from ..deprecator import ExpiredDeprecationError
 from .. import load as top_load
 
 
@@ -195,8 +196,8 @@ class DataLike(object):
     # Minimal class implementing 'data' API
     shape = (3,)
 
-    def __array__(self):
-        return np.arange(3, dtype=np.int16)
+    def __array__(self, dtype='int16'):
+        return np.arange(3, dtype=dtype)
 
 
 class TestSpatialImage(TestCase):
@@ -235,7 +236,7 @@ class TestSpatialImage(TestCase):
         # See https://github.com/nipy/nibabel/issues/58
         arr = np.arange(24, dtype=np.int16).reshape((2, 3, 4))
         img = self.image_class(arr, None)
-        assert_array_equal(img.get_data(), arr)
+        assert_array_equal(img.get_fdata(), arr)
         assert_equal(img.affine, None)
 
     def test_default_header(self):
@@ -252,9 +253,9 @@ class TestSpatialImage(TestCase):
         img = self.image_class(DataLike(), None)
         # Shape may be promoted to higher dimension, but may not reorder or
         # change size
-        assert_array_equal(img.get_data().flatten(), np.arange(3))
-        assert_equal(img.get_shape()[:1], (3,))
-        assert_equal(np.prod(img.get_shape()), 3)
+        assert_array_equal(img.get_fdata().flatten(), np.arange(3))
+        assert_equal(img.shape[:1], (3,))
+        assert_equal(np.prod(img.shape), 3)
 
     def check_dtypes(self, expected, actual):
         # Some images will want dtypes to be equal including endianness,
@@ -284,8 +285,8 @@ class TestSpatialImage(TestCase):
         img = img_klass(arr, np.eye(4))
         # Shape may be promoted to higher dimension, but may not reorder or
         # change size
-        assert_equal(img.get_shape()[:1], (4,))
-        assert_equal(np.prod(img.get_shape()), 4)
+        assert_equal(img.shape[:1], (4,))
+        assert_equal(np.prod(img.shape), 4)
         img = img_klass(np.zeros((2, 3, 4), dtype=np.float32), np.eye(4))
         assert_equal(img.shape, (2, 3, 4))
 
@@ -305,19 +306,13 @@ class TestSpatialImage(TestCase):
         assert_true(len(str(img)) > 0)
 
     def test_get_shape(self):
-        # Check there is a get_shape method
-        # (it is deprecated)
+        # Check that get_shape raises an ExpiredDeprecationError
         img_klass = self.image_class
         # Assumes all possible images support int16
         # See https://github.com/nipy/nibabel/issues/58
         img = img_klass(np.arange(1, dtype=np.int16), np.eye(4))
-        with suppress_warnings():
-            # Shape may be promoted to higher dimension, but may not reorder or
-            # change size
-            assert_equal(img.get_shape()[:1], (1,))
-            assert_equal(np.prod(img.get_shape()), 1)
-            img = img_klass(np.zeros((2, 3, 4), np.int16), np.eye(4))
-            assert_equal(img.get_shape(), (2, 3, 4))
+        with assert_raises(ExpiredDeprecationError):
+            img.get_shape()
 
     def test_get_fdata(self):
         # Test array image and proxy image interface for floating point data
@@ -389,9 +384,10 @@ class TestSpatialImage(TestCase):
                      "Cannot slice image objects; consider using "
                      "`img.slicer[slice]` to generate a sliced image (see "
                      "documentation for caveats) or slicing image array data "
-                     "with `img.dataobj[slice]` or `img.get_data()[slice]`")
+                     "with `img.dataobj[slice]` or `img.get_fdata()[slice]`")
         assert_true(in_data is img.dataobj)
-        out_data = img.get_data()
+        with assert_warns(DeprecationWarning):
+            out_data = img.get_data()
         assert_true(in_data is out_data)
         # and that uncache has no effect
         img.uncache()
@@ -403,15 +399,19 @@ class TestSpatialImage(TestCase):
         rt_img = bytesio_round_trip(img)
         assert_false(in_data is rt_img.dataobj)
         assert_array_equal(rt_img.dataobj, in_data)
-        out_data = rt_img.get_data()
+        with assert_warns(DeprecationWarning):
+            out_data = rt_img.get_data()
         assert_array_equal(out_data, in_data)
         assert_false(rt_img.dataobj is out_data)
         # cache
-        assert_true(rt_img.get_data() is out_data)
+        with assert_warns(DeprecationWarning):
+            assert_true(rt_img.get_data() is out_data)
         out_data[:] = 42
         rt_img.uncache()
-        assert_false(rt_img.get_data() is out_data)
-        assert_array_equal(rt_img.get_data(), in_data)
+        with assert_warns(DeprecationWarning):
+            assert_false(rt_img.get_data() is out_data)
+        with assert_warns(DeprecationWarning):
+            assert_array_equal(rt_img.get_data(), in_data)
 
     def test_slicer(self):
         img_klass = self.image_class
@@ -534,10 +534,14 @@ class TestSpatialImage(TestCase):
                         pass
                     else:
                         sliced_data = in_data[sliceobj]
-                        assert_array_equal(sliced_data, sliced_img.get_data())
+                        with assert_warns(DeprecationWarning):
+                            assert_array_equal(sliced_data, sliced_img.get_data())
+                        assert_array_equal(sliced_data, sliced_img.get_fdata())
                         assert_array_equal(sliced_data, sliced_img.dataobj)
                         assert_array_equal(sliced_data, img.dataobj[sliceobj])
-                        assert_array_equal(sliced_data, img.get_data()[sliceobj])
+                        with assert_warns(DeprecationWarning):
+                            assert_array_equal(sliced_data, img.get_data()[sliceobj])
+                        assert_array_equal(sliced_data, img.get_fdata()[sliceobj])
 
     def test_api_deprecations(self):
 
@@ -559,18 +563,14 @@ class TestSpatialImage(TestCase):
         bio = BytesIO()
         file_map = FakeImage.make_file_map({'image': bio})
 
-        with clear_and_catch_warnings() as w:
-            warnings.simplefilter('always', DeprecationWarning)
+        with assert_raises(ExpiredDeprecationError):
             img.to_files(file_map)
-            assert_equal(len(w), 1)
+        with assert_raises(ExpiredDeprecationError):
             img.to_filespec('an_image')
-            assert_equal(len(w), 2)
-            img = FakeImage.from_files(file_map)
-            assert_equal(len(w), 3)
-            file_map = FakeImage.filespec_to_files('an_image')
-            assert_equal(list(file_map), ['image'])
-            assert_equal(file_map['image'].filename, 'an_image.foo')
-            assert_equal(len(w), 4)
+        with assert_raises(ExpiredDeprecationError):
+            FakeImage.from_files(file_map)
+        with assert_raises(ExpiredDeprecationError):
+            FakeImage.filespec_to_files('an_image')
 
 
 class MmapImageMixin(object):
@@ -632,7 +632,7 @@ class MmapImageMixin(object):
                     if mmap is not None:
                         kwargs['mmap'] = mmap
                     back_img = func(param1, **kwargs)
-                    back_data = back_img.get_data()
+                    back_data = np.asanyarray(back_img.dataobj)
                     if expected_mode is None:
                         assert_false(isinstance(back_data, np.memmap),
                                      'Should not be a %s' % img_klass.__name__)
